// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The bytran logo is distributed under the Creative Commons 3.0 Attribution License: https://creativecommons.org/licenses/by/3.0/us/
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// QML component used to display the license to the user
import QtQuick 2.0
import QtQuick.Controls 1.3
import QtQuick.Window 2.2
import QtQuick.Dialogs 1.2
import QtQuick.Layouts 1.1

Item {

    id: licenseItem
    anchors.fill: parent

    // Used to rotate the menu
    onHeightChanged:
    {
        if (Screen.primaryOrientation == Qt.PortraitOrientation) { licenseColumnLayout.height = licenseItem.height - exitButton.height * 2.5 }
                                                            else { licenseColumnLayout.height = licenseItem.height - exitButton.height * 0.7 }
    }

    // Rectangle to draw the form border
    Rectangle {

        anchors.fill: parent
        border.width: 1
        border.color: "black"
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        anchors.right: licenseColumnLayout.right
        anchors.top: licenseColumnLayout.top
        anchors.left: licenseColumnLayout.left
        anchors.bottom: licenseColumnLayout.bottom
        anchors.margins: ((Qt.platform.os == 'ios') || (Qt.platform.os == 'android') || (Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? redLabel.height * (-0.425) : -20
        anchors.topMargin: ((Qt.platform.os == 'ios') || (Qt.platform.os == 'android') || (Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? redLabel.height * (-0.35) : -20
        color: "white"
        border.width: 1
        border.color: "black"
        radius: width * 0.02
    }

    // Qml component is used to display the license
    BackRectangle {
        anchors.fill: exitButton
        anchors.margins: 8
    }
    ColumnLayout
    {
        id: licenseColumnLayout
        anchors.centerIn: parent
        height: licenseItem.height - exitButton.height * 2.5

        Row {
            anchors.top: licenseColumnLayout.top
            id: mainRow

            Image {
                id: imageContainer
                height: redLabel.contentHeight
                fillMode: Image.PreserveAspectFit
                source: "/images/bytran256About.png"

                Rectangle
                {
                    anchors.fill: parent
                    color: 'white'
                }
            }

            Label {
                id: redLabel
                Layout.fillHeight: true
                text: "   bytran for mobile devices\n   Version 1.0 Beta | Kempsville edition"
                font.bold: false
                color: "white"
            }
        }

        TextArea {
            anchors.fill: parent
            id: mitLicenseTextArea
            readOnly: true
            selectByMouse: false
            textColor: 'black'
            backgroundVisible: false
            text:

"bytran -|- spectral calculations for portable devices using the HITRAN database\
\n\nDistributed under the MIT lincense\
\nCopyright (c) 2016 Dzianis Pliutau\
\nFirst made available under the Android operating system.  Version 1.0 Alpha for Android released on May 16, 2016
\
\nwww.bytran.org  |  info@bytran.org\
\nDeveloped by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov\
\
\n\nThis application was developed with Qt (https://www.qt.io/) distributed under LGPLv3 license. Parts of the calculation algorithm are based on the Python code from the HITRAN Application Programming Interface (HAPI) and other free documentation and posts available online.  \
\HAPI reference: R.V. Kochanov, I.E. Gordon, L.S. Rothman, P. Wcisło, C. Hill, J.S. Wilzewski, \"HITRAN Application Programming Interface (HAPI): A comprehensive approach to working with spectroscopic data\", JQSRT, Volume 177, July 2016, Pages 15–30; (hitran.org/hapi/).  \
\The Voigt calculation routine uses the algorithm described in: Abrarov, S., and Quine, B. (2015). \"A rational approximation for efficient computation of the Voigt function in quantitative spectroscopy\". Journal of Mathematics Research, 7(2), p 163. doi: http://dx.doi.org/10.5539/jmr.v7n2.  \
\Image and data sharing (Android and iOS) are based on the code Copyrighted (c) 2014 to Nicolas Froment at:  http://blog.lasconic.com/share-on-ios-and-android-using-qml/ and other sources.\
\
\n\nThe bytran logo is distributed under the Creative Commons 3.0 Attribution License: https://creativecommons.org/licenses/by/3.0/ \
\
\n\nThe MIT License (MIT)\
\nCopyright (c) 2016 Dzianis Pliutau\
\
\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the \"Software\"), \
to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, \
and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\
\
\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\
\
\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES \
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE \
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR \
IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE."

        }
    }

    // Button to close the form
    ControlButton {
        anchors.right: licenseItem.right
        anchors.top: licenseItem.top
        id: exitButton
        platformText: qsTr("X")
        opacity: 1.0

        // Enabling the closing of the form when the exit button is pressed
        MouseArea {
            anchors.fill: parent
            onClicked: {
                licenseItem.destroy();
            }
        }
    }
}

