// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// QML component to select the way the results are to be shared (SMS or email and so on)
import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Window 2.2
import QtQuick.Dialogs 1.2
import QtQuick.Layouts 1.1

Item {

    id: shareResultsChoiceItem
    anchors.fill: parent

    // Rectangle to draw the form border
    Rectangle {
        anchors.fill: parent
        border.width: 1
        border.color: "black"
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        anchors.right: buttonsRowLayout.right
        anchors.top: buttonsRowLayout.top
        anchors.left: buttonsRowLayout.left
        anchors.bottom: buttonsRowLayout.bottom
        anchors.margins: ((Qt.platform.os == 'ios') || (Qt.platform.os == 'android') || (Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? commentLabel.height * (-0.425) : -20
        color: "white"
        border.width: 1
        border.color: "black"
        radius: height * 0.02
    }

    // Button to close the form
    BackRectangle {
        anchors.fill: exitButton
        anchors.margins: 8
    }
    ControlButton {
        anchors.right: shareResultsChoiceItem.right
        anchors.top: shareResultsChoiceItem.top
        id: exitButton
        platformText: qsTr("X")
        opacity: 1.0

        // Enabling the closing of the form when the exit button is pressed
        MouseArea {
            anchors.fill: parent
            onClicked: {
                shareResultsChoiceItem.destroy();
            }
        }
    }

    ColumnLayout {

        // This feature is not available for Windows Phone message
        visible: (Qt.platform.os == 'winphone') ? true : false
        enabled: (Qt.platform.os == 'winphone') ? true : false
        anchors.centerIn: parent

        Label {
            anchors.centerIn: parent
            id: featureUnavailLabel
            text: qsTr("This capability is\ncurrently unavailable\nfor Windows Phone.")
            color: 'black'
            font.pointSize: 17
            horizontalAlignment: TextInput.AlignHCenter
        }
    }

    ColumnLayout {

        // This feature is temporary unavailable for Windows phone
        visible: (Qt.platform.os == 'winphone') ? false : true
        enabled: (Qt.platform.os == 'winphone') ? false : true

        id: buttonsRowLayout
        anchors.centerIn: parent
        anchors.bottom: infoLabel.bottom

        PlatformLabel {
            Layout.fillWidth: true
            id: commentLabel
            text: qsTr("The results of the calculations may\nbe shared and/or stored as follows:")
        }

        // Such conditional implementation was introduced to make sure the fonts look properly both under desktop as well as the mobile platforms
        // Need to test this more thoroughly under mobile platforms, not sure all platforms will result in descent looks
        AuxButton {
            id: shareButton           
            Layout.fillWidth: true
            platformText: qsTr("Share results")
            platformColor: 'black'

            // Enabling the closing of the form when the exit button is pressed
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if (shareResultsDataObj.dataAvailable)
                    {
                        shareResultsDataObj.shareResults = true;
                        shareResultsDataObj.saveToDocuments();
                        var component = Qt.createComponent("Notifier.qml")
                        if (component.status === Component.Ready)
                        {
                            shareResultsNotifierWindow = component.createObject(shareResultsChoiceItem)
                        }
                        shareResultsNotifierWindow.show()
                    }
                    else
                    {
                        shareResultsDataObj.showNoDataAlert()
                    }
                }
            }
        }

        Rectangle {
            Layout.fillWidth: true
            id: spacerRectangle1
            height: 1
            color: 'transparent'
            visible: ((Qt.platform.os == 'ios') || (Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? true : false
        }

        PlatformCheckBox {
            Layout.fillWidth: true
            id: attachImageCheckBox
            platformText: (Qt.platform.os == 'ios') ? qsTr("Attach image to message") : qsTr(" Attach image to message")
            checked: shareResultsDataObj.attachImage
            onCheckedChanged: shareResultsDataObj.attachImage = checked
            style: !((Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? referenceCheckBox.style : 0
        }
        // This weird way was introduced to enable text black color under the windows phone platform while maintaining the style a default for other platforms
        CheckBox {
            id: referenceCheckBox
            visible: false
        }

        Rectangle {
            Layout.fillWidth: true
            id: spacerRectangle2
            height: 1
            color: 'transparent'
            visible: ((Qt.platform.os == 'ios') || (Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone'))  ? true : false
        }

        PlatformCheckBox {
            Layout.fillWidth: true
            id: attachDataCheckBox
            platformText: (Qt.platform.os == 'ios') ? qsTr("Attach data file to message") : qsTr(" Attach data file to message")
            checked: shareResultsDataObj.attachDataFile
            onCheckedChanged: shareResultsDataObj.attachDataFile = checked
            style: !((Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? referenceCheckBox.style : 0
        }

        Rectangle {
            Layout.fillWidth: true
            id: spacerRectangle3
            height: 1
            color: 'transparent'
            visible: ((Qt.platform.os == 'ios') || (Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? true : false
        }

        Rectangle {
            Layout.fillWidth: true
            id: separatorRectangle
            height: 1
            color: 'black'
        }

        // Such conditional implementation was introduced to make sure the fonts look properly both under desktop as well as the mobile platforms
        // Need to test this more thoroughly under mobile platforms, not sure all platforms will result in descent looks
        AuxButton {
            id: saveToDocumentsButton
            Layout.fillWidth: true
            platformText: qsTr("   Save to Documents   ")
            platformColor: 'black'
            visible: coreObj.externalStorageAccessGranted ? true : false

            // Enabling the closing of the form when the exit button is pressed
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if (shareResultsDataObj.dataAvailable)
                    {
                        shareResultsDataObj.saveToDocuments();
                        var component = Qt.createComponent("Notifier.qml")
                        if (component.status === Component.Ready)
                        {
                            shareResultsNotifierWindow = component.createObject(shareResultsChoiceItem)
                        }
                        shareResultsNotifierWindow.show()
                    }
                    else
                    {
                        shareResultsDataObj.showNoDataAlert()
                    }
                }
            }
        }        

        PlatformLabel {
            Layout.fillWidth: true
            horizontalAlignment: Text.AlignCenter
            id: infoLabel
            text: coreObj.externalStorageAccessGranted ? qsTr("The image and data will be saved to\n\"Documents/bytran\" folder") : qsTr("Save to documents option not\navailable becuase the application\ndoes not have external storage\nread/write permission.")
        }
    }
}
