// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// QML component is used to specify the vertical scale units
import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Window 2.2
import QtQuick.Dialogs 1.2
import QtQuick.Layouts 1.1

Item {

    id: yAsisItem
    anchors.fill: parent

    // Rectangle to draw the form border
    Rectangle {
        anchors.fill: parent
        border.width: 1
        border.color: "black"
        color: Qt.rgba(0, 0, 0, 0.6)

        // This is introduced to disable items located on the background
        MouseArea {
            anchors.fill: parent
            onClicked: { }
        }
    }

    // Rectangle to draw the form border
    Rectangle {
        anchors.right: mainYAsisLayout.right
        anchors.top: mainYAsisLayout.top
        anchors.left: mainYAsisLayout.left
        anchors.bottom: mainYAsisLayout.bottom
        anchors.margins: ((Qt.platform.os == 'ios') || (Qt.platform.os == 'android') || (Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? minimumLabel.height * (-0.85) : -20
        color: "white"
        border.width: 1
        border.color: "black"
        radius: height * 0.03
    }

    // Button to close the form
    BackRectangle {
        anchors.fill: exitButton
        anchors.margins: 8
    }
    ControlButton {
        anchors.right: yAsisItem.right
        anchors.top: yAsisItem.top
        id: exitButton
        platformText: qsTr("X")
        opacity: 1.0

        // Enabling the closing of the form when the exit button is pressed
        MouseArea {
            anchors.fill: parent
            onClicked: {
                specResultsDataObj.updateYAxis();
                specResultsDataObj.updatePlotAllPreserveScale();
                yAsisItem.destroy();
            }
        }
    }

    // Column layout to hold all the interface items
    ColumnLayout {

        // At rotation the buttons are not positioned exactly the way they should be (fix this)
        id: mainYAsisLayout
        anchors.centerIn: parent
        spacing: 3
        transformOrigin: Item.Center
        Layout.fillWidth: true
        Layout.fillHeight: true

        PlatformLabel {
            Layout.fillWidth: true
            id: commentLabel
            text: qsTr("Specify the verctical scale units.")
        }

        GridLayout {

            rows: 3
            columns: 2

            PlatformLabel {
                id: minimumLabel
                anchors.right: minimumTextField.left
                Layout.column: 0
                Layout.row: 0
                text: qsTr("  Minimum:  ")
            }

            //Text field to specify minimum at Y axis
            PlatformTextField {
                Layout.fillWidth: true
                id: minimumTextField
                Layout.column: 1
                Layout.row: 0
                text: YAxisObj.minimum
                onTextChanged: YAxisObj.minimum = text
            }

            PlatformLabel {
                id: maximumLabel
                anchors.right: maximumTextField.left
                Layout.column: 0
                Layout.row: 1
                text: qsTr("  Maximum:  ")
            }

            // Text field to specify maximum at Y axis
            PlatformTextField {
                Layout.fillWidth: true
                id: maximumTextField
                Layout.column: 1
                Layout.row: 1
                text: YAxisObj.maximum
                onTextChanged: YAxisObj.maximum = text
            }

            PlatformLabel {
                id: unitsLabel
                anchors.right: unitsComboBox.left
                Layout.column: 0
                Layout.row: 2
                text: qsTr("  Units:  ")
            }

            // ComboBox to specify the vertical scale units
            PlatformComboBox  {
                id: unitsComboBox
                Layout.fillWidth: true
                Layout.column: 1
                Layout.row: 2
                model: [ "Absorption, %", "Transmission, %", "Optical depth"]
                currentIndex: YAxisObj.units
                onCurrentIndexChanged: {
                    YAxisObj.units = currentIndex
                }
                implicitWidth: maximumTextField.width
                style: ((Qt.platform.os == 'winrt') || (Qt.platform.os == 'winphone')) ? winReferenceComboBox.style : referenceComboBox.style
            }
            // This weird way was introduced to enable text black color under the windows phone platform while maintaining the style a default for other platforms
            PlatformComboBox {
                id: referenceComboBox
                visible: false
            }
            PlatformComboBox {
                id: winReferenceComboBox
                style: ComboBoxPlatformStyle {}
                visible: false
            }
        }
    }
}

