// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Data object to specify the HITRAN database download options
#include "hitrandownloadoptionsdataobject.h"
#include <QMessageBox>

HitranDownloadOptionsDataObject::HitranDownloadOptionsDataObject(QObject *parent, BytranCore *inCore) : QObject(parent)
{
    // Passing in a reference to the core object
    core = inCore;

    // Saving the value of the HITRAN database usage parameter
    m_hitranFileUsage = core->getHitranDownloader()->getHitranFileUsage();
}

int HitranDownloadOptionsDataObject::hitranFileUsage() const { return this->m_hitranFileUsage; }
void HitranDownloadOptionsDataObject::setHitranFileUsage(const int hitranFileUsage)
{
    if (hitranFileUsage != m_hitranFileUsage)
    {
        m_hitranFileUsage = hitranFileUsage;
        core->getHitranDownloader()->setHitranFileUsage(m_hitranFileUsage);
        emit hitranFileUsageChanged();
    }
}

// Method to check if the HITRAN database exists on the server
bool HitranDownloadOptionsDataObject::cumulativeHitranExists() const
{
    int value;

    value = core->getHitranDownloader()->getCompleteHitranDbFileExists();
    if ((value == 10) || (value == 11) || (value == 12) || (value == 1))
    {
        return true;
    }
    else
    {
        return false;
    }
}

// Method to download the complete HITRAN database
void HitranDownloadOptionsDataObject::downloadCompleteHitran()
{
    core->getHitranDownloader()->downloadCompleteSegmentedHitran();
}
