// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object is used to relay the notification information betweeen the C++ data objects and the QML interface
#ifndef NOTIFIERDATAOBJECT_H
#define NOTIFIERDATAOBJECT_H

#include <QObject>
#include "bytrancore.h"

class NotifierDataObject : public QObject
{
    Q_OBJECT

    Q_PROPERTY(QString notification READ notification WRITE setNotification NOTIFY notificationChanged)
    Q_PROPERTY(bool visible READ visible WRITE setVisible NOTIFY visibleChanged)
    Q_PROPERTY(double value READ value WRITE setValue NOTIFY valueChanged)
    Q_PROPERTY(double cancelButtonVisible READ cancelButtonVisible WRITE setCancelButtonVisible NOTIFY cancelButtonVisibleChanged)
    Q_PROPERTY(bool indeterminate READ indeterminate WRITE setIndeterminate NOTIFY indeterminateChanged)

public:

    explicit NotifierDataObject(QObject *parent = 0, BytranCore *inCore = 0);
    NotifierDataObject(const QString notification, const bool visible, QObject *parent = 0);

    QString notification() const;
    void setNotification(const QString &notification);

    bool visible() const;
    void setVisible(const bool &visible);

    double value() const;
    void setValue(const double &value);

    bool indeterminate() const;
    void setIndeterminate(const bool &indeterminate);

    bool cancelButtonVisible() const;
    void setCancelButtonVisible(const bool cancelButtonVisible);

signals:

    void notificationChanged();
    void visibleChanged();
    void valueChanged();
    void indeterminateChanged();
    void cancelButtonVisibleChanged();

private:

    // Method to create connections
    void createActions();

    BytranCore *core;
    QString m_notification;
    bool m_visible;
    bool m_cancelButtonVisible;
    double m_value;
    bool m_indeterminate;

private slots:

    // Slot to display a status notification
    void updateNotifications(QString message, double value, bool visible, bool cancelButtonVisible);

};

#endif // NOTIFIERDATAOBJECT_H
