// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object to containing information about a single atmospheric model
#include "oneatmmodel.h"
#include "auxiliary.h"
#include <QMessageBox>

OneAtmModel::OneAtmModel()
{
}

// Getting and setting the atmospheric model parameters
Spectrum *OneAtmModel::getTotalPress() { return &(this->totalPress); }
void OneAtmModel::setTotalPress(Spectrum *newTotalPress)
{
    Auxiliary::copySpectrum(newTotalPress, &totalPress);
}
Spectrum *OneAtmModel::getTemp() { return &(this->temp); }
void OneAtmModel::setTemp(Spectrum *newTemp)
{
    Auxiliary::copySpectrum(newTemp, &temp);
}
Spectrum *OneAtmModel::getDensity() { return &(this->density); }
void OneAtmModel::setDensity(Spectrum *newDensity)
{
    Auxiliary::copySpectrum(newDensity, &density);
}

// Getting and setting the partial pressure
QVector<Spectrum> *OneAtmModel::getPartPressArray() { return &(this->partPress); }
Spectrum *OneAtmModel::getPartPressSpecByMolIndex(int molIndex) { return &(this->partPress[molIndex]); }
void OneAtmModel::setPartPressSpecByMolIndex(int molIndex, Spectrum *partPressSpec) { partPress[molIndex] = *partPressSpec; }
void OneAtmModel::resizePartPressArray(int newSize) { this->partPress.resize(newSize); }

// Getting and setting the model name
QString OneAtmModel::getModelName() { return this->modelName; }
void OneAtmModel::setModelName(QString newModelName) { this->modelName = newModelName; }

// Method to get the number of molecules in the model
int OneAtmModel::getNumMolecules() { return this->partPress.count(); }

// Method to append a new partial pressure spectrum (for a given molecule) to the array of partial pressure spectra
void OneAtmModel::appendPartPress(Spectrum *newPartPressSpec)
{
    this->partPress.append(*newPartPressSpec);
}
