// bytran -|- spectral calculations for portable devices using the HITRAN database
//
// Developed by Dzianis Pliutau (Denis Plutov) and Kostya Roslyakov
// www.bytran.org | info@bytran.org
// Copyright (c) 2016 Dzianis Pliutau
// Distributed under the MIT license
//
// The MIT License (MIT)
// Copyright (c) 2016 Dzianis Pliutau
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
// is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
// IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.



// Object is used to relay the temperature information betweeen the C++ data objects and the QML interface
#include "temperaturedataobject.h"
#include <QLocale>
#include <QMessageBox>

TemperatureDataObject::TemperatureDataObject(QObject *parent, BytranCore *inCore) : QObject(parent)
{
    QLocale loc;
    double tempK;  // Temperature in Kelvin units
    double tempCurrUnits;  // Temperature in current units


    // Passing in the core object
    core = inCore;
    tempK = core->getParams()->getHorizParams()->getTemp();
    tempCurrUnits = core->getTemperatureUnitsConverter()->fromDefaultToCurrent(tempK);
    m_Temperature = loc.toString(tempCurrUnits, 'g', 6);
    m_units = core->getTemperatureUnitsConverter()->getUnits();
}

QString TemperatureDataObject::temperature() const
{
    QLocale loc;
    double tempK;  // Temperature in Kelvin units
    double tempCurrUnits;  // Temperature in current units
    QString temperature;


    tempK = core->getParams()->getHorizParams()->getTemp();
    tempCurrUnits = core->getTemperatureUnitsConverter()->fromDefaultToCurrent(tempK);
    return loc.toString(tempCurrUnits, 'g', 6);
}

void TemperatureDataObject::setTemperature(const QString &temperature)
{
    QLocale c;  // Object to convert strings into numerical variables
    double tempDefaultUnits;  // Temperature in current units to be converted to Kelvin


    if (temperature != m_Temperature) {
        m_Temperature = temperature;
        // Need to convert the value to default units (mbar)
        tempDefaultUnits = core->getTemperatureUnitsConverter()->fromCurrentToDefault(c.toDouble(temperature));
        core->getParams()->getHorizParams()->setTemp(tempDefaultUnits);
        emit temperatureChanged();
    }
}

int TemperatureDataObject::units() const
{
    return m_units;
}

void TemperatureDataObject::setUnits(const int &units)
{
    QLocale loc;
    double tempK;  // Temperature in Kelvin units
    double tempCurrUnits;  // Temperature in current units


    if (units != m_units) {
        m_units = units;
        // Saving the units into the object used to convert to different pathlength measurement units
        core->getTemperatureUnitsConverter()->setUnits(m_units);

        // Updating the displayed temperature
        tempK = core->getParams()->getHorizParams()->getTemp();
        tempCurrUnits = core->getTemperatureUnitsConverter()->fromDefaultToCurrent(tempK);
        m_Temperature = loc.toString(tempCurrUnits, 'g', 6);

        emit unitsChanged();
        emit temperatureChanged();
    }
}
